@@ -9,8 +9,8 @@ Sunlight Congress API Implementation inside ``python-sunlight``.
 """
 
 import sunlight.service
-from sunlight.service import EntityList
-from sunlight.service import EntityDict
+from sunlight.service import EntityDict, EntityList
+from sunlight.pagination import pageable
 import json
 
 
@@ -51,6 +51,9 @@ class Congress(sunlight.service.Service):
     is the place to look for help on field names and examples.
     """
 
+    is_pageable = True
+
+    @pageable
     def legislators(self, **kwargs):
         """
         Search and filter for members of Congress.
@@ -60,6 +63,7 @@ class Congress(sunlight.service.Service):
         """
         return self.get('legislators', **kwargs)
 
+    @pageable
     def legislator(self, identifier, id_type=LEGISLATOR_ID_TYPES[0], **kwargs):
         """
         Retrieve a member of Congress by a unique identifier. Defaults to
@@ -91,25 +95,25 @@ class Congress(sunlight.service.Service):
             return EntityDict(results[0], results._meta)
         return None
 
-
     def all_legislators_in_office(self, **kwargs):
         """
         Returns all legislators currently in office (non-paginated response).
 
         For details see `Legislators API docs
-        <http://sunlightlabs.github.io/congress/legislators.html>`
+        <http://sunlightlabs.github.io/congress/legislators.html>`_
         """
         kwargs.update({
             "per_page": "all"
         })
         return self.get('legislators', **kwargs)
 
+    @pageable
     def locate_legislators_by_lat_lon(self, lat, lon, **kwargs):
         """
         Find members of Congress by a latitude and longitude.
 
         For details see `Legislators API docs
-        <http://sunlightlabs.github.io/congress/legislators.html#methods/legislators-locate>`
+        <http://sunlightlabs.github.io/congress/legislators.html#methods/legislators-locate>`_
         """
         kwargs.update({
             "latitude": lat,
@@ -117,33 +121,36 @@ class Congress(sunlight.service.Service):
         })
         return self.get('legislators/locate', **kwargs)
 
+    @pageable
     def locate_legislators_by_zip(self, zipcode, **kwargs):
         """
         Find members of Congress by zip code.
 
         For details see `Legislators API docs
-        <http://sunlightlabs.github.io/congress/legislators.html#methods/legislators-locate>`
+        <http://sunlightlabs.github.io/congress/legislators.html#methods/legislators-locate>`_
         """
         kwargs.update({
             "zip": zipcode
         })
         return self.get('legislators/locate', **kwargs)
 
+    @pageable
     def bills(self, **kwargs):
         """
         Search and filter through bills in Congress.
 
         For details see `Bills API docs
-        <http://sunlightlabs.github.io/congress/bills.html>`
+        <http://sunlightlabs.github.io/congress/bills.html>`_
         """
         return self.get('bills', **kwargs)
 
+    @pageable
     def bill(self, bill_id, **kwargs):
         """
         Retrieve a bill by bill_id.
 
         For details see `Bills API docs
-        <http://sunlightlabs.github.io/congress/bills.html>`
+        <http://sunlightlabs.github.io/congress/bills.html>`_
         """
         kwargs.update({
             "bill_id": bill_id
@@ -153,18 +160,20 @@ class Congress(sunlight.service.Service):
             return EntityDict(results[0], results._meta)
         return None
 
+    @pageable
     def search_bills(self, query, **kwargs):
         """
         Search the full text of legislation, and other fields.
 
-        For details see `Bills API docs
-        <http://sunlightlabs.github.io/congress/bills.html#methods/bills-search>`
+        For details see `Bill search API docs
+        <http://sunlightlabs.github.io/congress/bills.html#methods/bills-search>`_
         """
         kwargs.update({
             "query": query
         })
         return self.get('bills/search', **kwargs)
 
+    @pageable
     def upcoming_bills(self, **kwargs):
         """
         Search and filter through upcoming bills in the House and Senate.
@@ -173,16 +182,17 @@ class Congress(sunlight.service.Service):
         party leadership for upcoming House and Senate floor action.
 
         For details see `Upcoming Bills API docs
-        <http://sunlightlabs.github.io/congress/upcoming_bills.html>`
+        <http://sunlightlabs.github.io/congress/upcoming_bills.html>`_
         """
         return self.get('upcoming_bills', **kwargs)
 
+    @pageable
     def locate_districts_by_lat_lon(self, lat, lon, **kwargs):
         """
         Find congressional districts by a latitude and longitude.
 
         For details see `Districts API docs
-        <http://sunlightlabs.github.io/congress/districts.html>`
+        <http://sunlightlabs.github.io/congress/districts.html>`_
         """
         kwargs.update({
             "latitude": lat,
@@ -190,69 +200,76 @@ class Congress(sunlight.service.Service):
         })
         return self.get('/districts/locate', **kwargs)
 
+    @pageable
     def locate_districts_by_zip(self, zipcode, **kwargs):
         """
         Find congressional districts by a latitude and longitude.
 
         For details see `Districts API docs
-        <http://sunlightlabs.github.io/congress/districts.html>`
+        <http://sunlightlabs.github.io/congress/districts.html>`_
         """
         kwargs.update({
             "zip": zipcode,
         })
         return self.get('/districts/locate', **kwargs)
 
+    @pageable
     def committees(self, **kwargs):
         """
         Search and filter through committees in the House and Senate.
 
         For details see `Committees API docs
-        <http://sunlightlabs.github.io/congress/committees.html>`
+        <http://sunlightlabs.github.io/congress/committees.html>`_
         """
         return self.get('committees', **kwargs)
 
+    @pageable
     def amendments(self, **kwargs):
         """
         Search and filter through amendments in Congress.
 
         For details see `Amendments API docs
-        <http://sunlightlabs.github.io/congress/amendments.html>`
+        <http://sunlightlabs.github.io/congress/amendments.html>`_
         """
         return self.get('amendments', **kwargs)
 
+    @pageable
     def votes(self, **kwargs):
         """
         Search and filter through votes in Congress.
 
         For details see `Votes API docs
-        <http://sunlightlabs.github.io/congress/votes.html>`
+        <http://sunlightlabs.github.io/congress/votes.html>`_
         """
         return self.get('votes', **kwargs)
 
+    @pageable
     def floor_updates(self, **kwargs):
         """
         Search and filter through floor updates in the House and Senate.
 
         For details see `Floor Updates API docs
-        <http://sunlightlabs.github.io/congress/floor_updates.html>`
+        <http://sunlightlabs.github.io/congress/floor_updates.html>`_
         """
         return self.get('floor_updates', **kwargs)
 
+    @pageable
     def hearings(self, **kwargs):
         """
         Search and filter through committee hearings in the House and Senate.
 
         For details see `Hearings API docs
-        <http://sunlightlabs.github.io/congress/hearings.html>`
+        <http://sunlightlabs.github.io/congress/hearings.html>`_
         """
         return self.get('hearings', **kwargs)
 
+    @pageable
     def nominations(self, **kwargs):
         """
         Search and filter through presidential nominations in Congress.
 
         For details see `Nominations API docs
-        <http://sunlightlabs.github.io/congress/nominations.html>`
+        <http://sunlightlabs.github.io/congress/nominations.html>`_
         """
         return self.get('nominations', **kwargs)
 
